summaryrefslogtreecommitdiffstats
path: root/filters
diff options
context:
space:
mode:
authorDudemanguy <random342@airmail.cc>2024-01-20 20:45:00 -0600
committerDudemanguy <random342@airmail.cc>2024-01-21 17:55:54 +0000
commit45f822593f14d78fa22e74fa4e725a3ffd6f713c (patch)
treeb34e4d166cde0bd2286170b3546bfc51ddec59ff /filters
parent02a20b4ebe29cb7d488ceaf39fb5a50c2443295a (diff)
downloadmpv-45f822593f14d78fa22e74fa4e725a3ffd6f713c.tar.bz2
mpv-45f822593f14d78fa22e74fa4e725a3ffd6f713c.tar.xz
f_auto_filters: change fallback deinterlace to bwdif
I don't actually deinterlace ever but allegedly this is better than yadif, and there's no real reason to not have this be the fallback deinterlace when we're not using hw frames. Also change various mentions of yadif to bwdif. Ref #12835.
Diffstat (limited to 'filters')
-rw-r--r--filters/f_auto_filters.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/filters/f_auto_filters.c b/filters/f_auto_filters.c
index c8b31f60fb..ce7ffaaf90 100644
--- a/filters/f_auto_filters.c
+++ b/filters/f_auto_filters.c
@@ -107,7 +107,7 @@ static void deint_process(struct mp_filter *f)
struct mp_autoconvert *ac = mp_autoconvert_create(subf);
if (ac) {
filters[0] = ac->f;
// We know vf_yadif does not support hw inputs.
mp_autoconvert_add_all_sw_imgfmts(ac);
if (!mp_autoconvert_probe_input_video(ac, img)) {
@@ -121,7 +121,7 @@ static void deint_process(struct mp_filter *f)
char *args[] = {"mode", "send_field", NULL};
filters[1] =
- mp_create_user_filter(subf, MP_OUTPUT_CHAIN_VIDEO, "yadif", args);
+ mp_create_user_filter(subf, MP_OUTPUT_CHAIN_VIDEO, "bwdif", args);
mp_chain_filters(subf->ppins[0], subf->ppins[1], filters, 2);
p->sub.filter = subf;
@@ -107,7 +107,7 @@ static void deint_process(struct mp_filter *f)
if (ac) {
filters[0] = ac->f;
- // We know vf_yadif does not support hw inputs.
+ // We know vf_bwdif does not support hw inputs.
mp_autoconvert_add_all_sw_imgfmts(ac);
if (!mp_autoconvert_probe_input_video(ac, img)) {